<?php
/*
Plugin Name: Coupons Month Limiter (EasyToolsWP)
Description: Adds a dropdown to coupons to limit them to specific months.
Version: 1.0.2
Author: EasyToolsWP.com
Requires Plugins:  woocommerce
*/

defined( 'ABSPATH' ) || exit;

// Add custom fields to coupon form
add_action( 'woocommerce_coupon_options', 'add_month_limit_field' );
function add_month_limit_field() {
    global $post;

    echo '<div class="options_group">';
    woocommerce_wp_select( array(
        'id'            => 'month_limit',
        'label'         => __( 'Month Limit', 'woocommerce' ),
        'description'   => __( 'Choose month to limit this coupon.', 'woocommerce' ),
        'options'       => array(
            ''             => __( 'No Restriction', 'woocommerce' ),
            'january'      => __( 'January', 'woocommerce' ),
            'february'     => __( 'February', 'woocommerce' ),
            'march'        => __( 'March', 'woocommerce' ),
            'april'        => __( 'April', 'woocommerce' ),
            'may'          => __( 'May', 'woocommerce' ),
            'june'         => __( 'June', 'woocommerce' ),
            'july'         => __( 'July', 'woocommerce' ),
            'august'       => __( 'August', 'woocommerce' ),
            'september'    => __( 'September', 'woocommerce' ),
            'october'      => __( 'October', 'woocommerce' ),
            'november'     => __( 'November', 'woocommerce' ),
            'december'     => __( 'December', 'woocommerce' ),
        ),
    ) );
    echo '</div>';
}

// Save custom fields
add_action( 'woocommerce_coupon_options_save', 'save_month_limit_field' );
function save_month_limit_field( $post_id ) {
    $month_limit = isset( $_POST['month_limit'] ) ? sanitize_text_field( $_POST['month_limit'] ) : '';
    update_post_meta( $post_id, 'month_limit', $month_limit );
}

// Check if coupon is valid for current month
add_filter( 'woocommerce_coupon_is_valid', 'check_month_coupon_validity', 10, 2 );
function check_month_coupon_validity( $is_valid, $coupon ) {
    $month_limit = get_post_meta( $coupon->get_id(), 'month_limit', true );

    if ( ! empty( $month_limit ) ) {
        $current_month = strtolower( date( 'F' ) ); // Get current month in full text lowercase

        // Check if current month matches the coupon's month limit
        if ( $current_month !== $month_limit ) {
            $is_valid = false;
        }
    }

    return $is_valid;
}

// Function to create coupons for all months on plugin activation
register_activation_hook( __FILE__, 'create_month_coupons' );
function create_month_coupons() {
    $coupons = array(
        'january_coupon' => array(
            'month_limit'     => 'january',
            'amount'          => 10, //
        ),
        'february_coupon' => array(
            'month_limit'     => 'february',
            'amount'          => 10, //
        ),
        'march_coupon' => array(
            'month_limit'     => 'march',
            'amount'          => 10, //
        ),
        'april_coupon' => array(
            'month_limit'     => 'april',
            'amount'          => 10, //
        ),
        'may_coupon' => array(
            'month_limit'     => 'may',
            'amount'          => 10, // 
        ),
        'june_coupon' => array(
            'month_limit'     => 'june',
            'amount'          => 10, //
        ),
        'july_coupon' => array(
            'month_limit'     => 'july',
            'amount'          => 10, //
        ),
        'august_coupon' => array(
            'month_limit'     => 'august',
            'amount'          => 10, // 
        ),
        'september_coupon' => array(
            'month_limit'     => 'september',
            'amount'          => 10, // 
        ),
        'october_coupon' => array(
            'month_limit'     => 'october',
            'amount'          => 10, // 
        ),
        'november_coupon' => array(
            'month_limit'     => 'november',
            'amount'          => 10, // 
        ),
        'december_coupon' => array(
            'month_limit'     => 'december',
            'amount'          => 10, // 
        ),
    );

    foreach ( $coupons as $coupon_code => $coupon_args ) {
        $coupon = new WC_Coupon();
        $coupon->set_code( $coupon_code );
        $coupon->set_discount_type( 'percent' ); // Rabattype som procent
        $coupon->set_amount( $coupon_args['amount'] ); // Procentrabat beløb
        $coupon->set_individual_use( true );
        $coupon->set_usage_limit( 1 );

        // Set month limit metadata
        update_post_meta( $coupon->get_id(), 'month_limit', $coupon_args['month_limit'] );

        $coupon->save();
    }
}
